BadGatewayException class

Exception thrown for 502 Bad Gateway errors.

Inheritance

Constructors

BadGatewayException(String message, {Uri? uri, dynamic responseBody, Map<String, String>? headers, StackTrace? stackTrace})

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
finalinherited
isClientError → bool
Check if this is a client error (4xx)
no setterinherited
isNetworkError → bool
Check if this is a network/connection error
no setterinherited
isServerError → bool
Check if this is a server error (5xx)
no setterinherited
message → String
finalinherited
responseBody → dynamic
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
finalinherited
statusCode → int?
finalinherited
timestamp → DateTime
finalinherited
uri → Uri?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDetailedString() → String
Returns a detailed error report for debugging
inherited
toMap() → Map<String, dynamic>
Convert exception to Map for logging or serialization
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited