CachedResponse<T> class

Cached response data for HTTP caching

Constructors

CachedResponse({required Response<T> response, required DateTime cachedAt, required Duration maxAge})

Properties

cachedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
no setter
maxAge Duration
final
response Response<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited