onError property
Builder for the error state. Defaults to a professional error view with retry button.
Implementation
final Widget Function(
BuildContext context, Object error, VoidCallback? onRetry)? onError;
Builder for the error state. Defaults to a professional error view with retry button.
final Widget Function(
BuildContext context, Object error, VoidCallback? onRetry)? onError;