GetConnect class
- Inheritance
-
- Object
- GetConnectInterface
- GetConnect
Constructors
Properties
- allowAutoSignedCert ↔ bool
-
getter/setter pair
- baseUrl ↔ String?
-
getter/setter pair
- cacheMaxAge ↔ Duration
-
getter/setter pair
- defaultContentType ↔ String
-
getter/setter pair
- defaultDecoder ↔ Decoder?
-
getter/setter pair
- enableCaching ↔ bool
-
getter/setter pair
- enableLogging ↔ bool
-
getter/setter pair
- enableRetry ↔ bool
-
getter/setter pair
- findProxy ↔ String Function(Uri url)?
-
getter/setter pair
- followRedirects ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClient → GetHttpClient
-
no setteroverride
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isDisposed → bool
-
no setter
- maxAuthRetries ↔ int
-
getter/setter pair
- maxRedirects ↔ int
-
getter/setter pair
- maxRetries ↔ int
-
getter/setter pair
-
onDelete
→ InternalFinalCallback<
void> -
Internal callback that starts the cycle of this controller.
finalinherited
-
onStart
→ InternalFinalCallback<
void> -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
finalinherited
- retryDelay ↔ Duration
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendUserAgent ↔ bool
-
getter/setter pair
-
sockets
↔ List<
GetSocket> -
getter/setter pairinherited-setteroverride-getter
- timeout ↔ Duration
-
getter/setter pair
-
trustedCertificates
↔ List<
TrustedCertificate> ? -
getter/setter pair
- userAgent ↔ String
-
getter/setter pair
- withCredentials ↔ bool
-
getter/setter pair
Methods
-
$configureLifeCycle(
) → void -
inherited
-
clearCache(
) → void - Clear HTTP cache
-
delete<
T> (String url, {Map< String, String> ? headers, String? contentType, Map<String, dynamic> ? query, Decoder<T> ? decoder}) → Future<Response< T> > -
Performs a DELETE request to remove a resource.
override
-
dispose(
) → void -
get<
T> (String url, {Map< String, String> ? headers, String? contentType, Map<String, dynamic> ? query, Decoder<T> ? decoder}) → Future<Response< T> > -
Performs a GET request to the specified URL.
override
-
getCached<
T> (String url, {Map< String, String> ? headers, String? contentType, Map<String, dynamic> ? query, Decoder<T> ? decoder, bool useCache = true}) → Future<Response< T> > - Enhanced GET with caching and retry
-
mutation<
T> (String mutation, {String? url, Map< String, dynamic> ? variables, Map<String, String> ? headers}) → Future<GraphQLResponse< T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
patch<
T> (String url, dynamic body, {String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
Performs a PATCH request to partially update a resource.
override
-
post<
T> (String? url, dynamic body, {String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
Performs a POST request to create or submit data to the specified URL.
override
-
put<
T> (String url, dynamic body, {String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
Performs a PUT request to update an entire resource at the specified URL.
override
-
query<
T> (String query, {String? url, Map< String, dynamic> ? variables, Map<String, String> ? headers}) → Future<GraphQLResponse< T> > -
query allow made GraphQL raw queries
final connect = GetConnect();
connect.baseUrl = 'https://countries.trevorblades.com/';
final response = await connect.query(
r"""
{
country(code: "BR") {
name
native
currency
languages {
code
name
}
}
}
""",
);
print(response.body);
override
-
request<
T> (String url, String method, {dynamic body, String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
Performs a custom HTTP request with the specified method.
override
-
socket(
String url, {Duration ping = const Duration(seconds: 5)}) → GetSocket -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited