GetNavigation extension

on

Properties

arguments → dynamic

Available on GetInterface, provided by the GetNavigation extension

give current arguments
no setter
bottomBarHeight → double

Available on GetInterface, provided by the GetNavigation extension

The distance from the bottom edge to the first unpadded pixel, in physical pixels.
no setter
context → BuildContext?

Available on GetInterface, provided by the GetNavigation extension

give access to currentContext
no setter
currentRoute → String

Available on GetInterface, provided by the GetNavigation extension

give name from current route
no setter
customTransition ↔ CustomTransition?

Available on GetInterface, provided by the GetNavigation extension

getter/setter pair
defaultDialogTransitionCurve → Curve

Available on GetInterface, provided by the GetNavigation extension

no setter
defaultDialogTransitionDuration → Duration

Available on GetInterface, provided by the GetNavigation extension

no setter
defaultOpaqueRoute → bool

Available on GetInterface, provided by the GetNavigation extension

no setter
defaultPopGesture → bool

Available on GetInterface, provided by the GetNavigation extension

no setter
defaultTransition → Transition?

Available on GetInterface, provided by the GetNavigation extension

no setter
defaultTransitionCurve → Curve

Available on GetInterface, provided by the GetNavigation extension

no setter
defaultTransitionDuration → Duration

Available on GetInterface, provided by the GetNavigation extension

no setter
deviceLocale → Locale?

Available on GetInterface, provided by the GetNavigation extension

no setter
engine → WidgetsBinding

Available on GetInterface, provided by the GetNavigation extension

The current WidgetsBinding
no setter
focusScope → FocusNode?

Available on GetInterface, provided by the GetNavigation extension

give access to FocusScope.of(context)
no setter
height → double

Available on GetInterface, provided by the GetNavigation extension

The vertical extent of this size
no setter
iconColor → Color?

Available on GetInterface, provided by the GetNavigation extension

give access to Theme.of(context).iconTheme.color
no setter
isBottomSheetOpen → bool?

Available on GetInterface, provided by the GetNavigation extension

check if bottomSheet is open
no setter
isDarkMode → bool

Available on GetInterface, provided by the GetNavigation extension

Check if dark mode theme is enable
no setter
isDialogOpen → bool?

Available on GetInterface, provided by the GetNavigation extension

check if dialog is open
no setter
isOpaqueRouteDefault → bool

Available on GetInterface, provided by the GetNavigation extension

check if default opaque route is enable
no setter
isOverlaysClosed → bool

Available on GetInterface, provided by the GetNavigation extension

Returns true if there is no Snackbar, Dialog or BottomSheet open
no setter
isOverlaysOpen → bool

Available on GetInterface, provided by the GetNavigation extension

Returns true if a Snackbar, Dialog or BottomSheet is currently OPEN
no setter
isPlatformDarkMode → bool

Available on GetInterface, provided by the GetNavigation extension

Check if dark mode theme is enable on platform on android Q+
no setter
isPopGestureEnable → bool

Available on GetInterface, provided by the GetNavigation extension

check if popGesture is enable
no setter
isSnackbarOpen → bool

Available on GetInterface, provided by the GetNavigation extension

check if snackbar is open
no setter
key → GlobalKey<NavigatorState>

Available on GetInterface, provided by the GetNavigation extension

no setter
keys → Map<dynamic, GlobalKey<NavigatorState>>

Available on GetInterface, provided by the GetNavigation extension

no setter
mediaQuery → MediaQueryData

Available on GetInterface, provided by the GetNavigation extension

give access to Mediaquery.of(context)
no setter
overlayContext → BuildContext?

Available on GetInterface, provided by the GetNavigation extension

give access to current Overlay Context
no setter
parameters ↔ Map<String, String?>

Available on GetInterface, provided by the GetNavigation extension

getter/setter pair
pixelRatio → double

Available on GetInterface, provided by the GetNavigation extension

The number of device pixels for each logical pixel.
no setter
previousRoute → String

Available on GetInterface, provided by the GetNavigation extension

give name from previous route
no setter
rawRoute → Route?

Available on GetInterface, provided by the GetNavigation extension

check a raw current route
no setter
rootController → GetMaterialController

Available on GetInterface, provided by the GetNavigation extension

no setter
routing → Routing

Available on GetInterface, provided by the GetNavigation extension

no setter
size → Size

Available on GetInterface, provided by the GetNavigation extension

no setter
statusBarHeight → double

Available on GetInterface, provided by the GetNavigation extension

The distance from the top edge to the first unpadded pixel, in physical pixels.
no setter
testMode ↔ bool

Available on GetInterface, provided by the GetNavigation extension

getter/setter pair
textScaleFactor → double

Available on GetInterface, provided by the GetNavigation extension

The system-reported text scale.
no setter
textTheme → TextTheme

Available on GetInterface, provided by the GetNavigation extension

give access to TextTheme.of(context)
no setter
theme → ThemeData

Available on GetInterface, provided by the GetNavigation extension

give access to Theme.of(context)
no setter
width → double

Available on GetInterface, provided by the GetNavigation extension

The horizontal extent of this size.
no setter
window → FlutterView?

Available on GetInterface, provided by the GetNavigation extension

The window to which this binding is bound.
no setter

Methods

addKey(GlobalKey<NavigatorState> newKey) → GlobalKey<NavigatorState>?

Available on GetInterface, provided by the GetNavigation extension

Example:
appUpdate() → void

Available on GetInterface, provided by the GetNavigation extension

Example:
back<T>({T? result, bool closeOverlays = false, bool canPop = true, int? id}) → void

Available on GetInterface, provided by the GetNavigation extension

Navigation.popUntil() shortcut.

changeTheme(ThemeData theme) → void

Available on GetInterface, provided by the GetNavigation extension

Example:
changeThemeMode(ThemeMode themeMode) → void

Available on GetInterface, provided by the GetNavigation extension

Example:
close(int times, [int? id]) → void

Available on GetInterface, provided by the GetNavigation extension

Navigation.popUntil() (with predicate) shortcut .

closeAllSnackbars() → void

Available on GetInterface, provided by the GetNavigation extension

Example:
closeCurrentSnackbar() → Future<void>

Available on GetInterface, provided by the GetNavigation extension

Example:
config({bool? enableLog, LogWriterCallback? logWriterCallback, bool? defaultPopGesture, bool? defaultOpaqueRoute, Duration? defaultDurationTransition, bool? defaultGlobalState, Transition? defaultTransition}) → void

Available on GetInterface, provided by the GetNavigation extension

change default config of Get
forceAppUpdate() → Future<void>

Available on GetInterface, provided by the GetNavigation extension

Example:
global(int? k) → GlobalKey<NavigatorState>

Available on GetInterface, provided by the GetNavigation extension

Example:
nestedKey(dynamic key) → GlobalKey<NavigatorState>?

Available on GetInterface, provided by the GetNavigation extension

Example:
off<T>(dynamic page, {bool opaque = false, Transition? transition, Curve? curve, bool? popGesture, int? id, String? routeName, dynamic arguments, Bindings? binding, bool fullscreenDialog = false, bool preventDuplicates = true, Duration? duration, double gestureWidth(BuildContext context)?, ConditionalNavigationOff? conditionOff}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.pushReplacement() shortcut .

offAll<T>(dynamic page, {RoutePredicate? predicate, bool opaque = false, bool? popGesture, int? id, String? routeName, dynamic arguments, Bindings? binding, bool fullscreenDialog = false, Transition? transition, Curve? curve, Duration? duration, double gestureWidth(BuildContext context)?, ConditionalNavigationOffAll? conditionOffAll}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Push a page and pop several pages in the stack until predicate returns true. predicate is optional
offAllNamed<T>(String newRouteName, {RoutePredicate? predicate, dynamic arguments, int? id, Map<String, String>? parameters}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.pushNamedAndRemoveUntil() shortcut.

offAndToNamed<T>(String page, {dynamic arguments, int? id, dynamic result, Map<String, String>? parameters}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.popAndPushNamed() shortcut.

offNamed<T>(String page, {dynamic arguments, int? id, bool preventDuplicates = true, Map<String, String>? parameters}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.pushReplacementNamed() shortcut.

offNamedUntil<T>(String page, RoutePredicate predicate, {int? id, dynamic arguments, Map<String, String>? parameters}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.pushNamedAndRemoveUntil() shortcut.

offUntil<T>(Route<T> page, RoutePredicate predicate, {int? id}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.pushAndRemoveUntil() shortcut.

removeRoute(Route route, {int? id}) → void

Available on GetInterface, provided by the GetNavigation extension

Navigation.removeRoute() shortcut.

resetRootNavigator() → void

Available on GetInterface, provided by the GetNavigation extension

to<T>(dynamic page, {bool? opaque, Transition? transition, Curve? curve, Duration? duration, int? id, String? routeName, bool fullscreenDialog = false, dynamic arguments, Bindings? binding, bool preventDuplicates = true, bool? popGesture, double gestureWidth(BuildContext context)?, ConditionalNavigation? condition}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.push() shortcut.

toNamed<T>(String page, {dynamic arguments, int? id, bool preventDuplicates = true, Map<String, String>? parameters}) → Future<T?>?

Available on GetInterface, provided by the GetNavigation extension

Navigation.pushNamed() shortcut.

until(RoutePredicate predicate, {int? id}) → void

Available on GetInterface, provided by the GetNavigation extension

Navigation.popUntil() shortcut.

updateLocale(Locale l) → Future<void>

Available on GetInterface, provided by the GetNavigation extension

Example: