GetRealtimeResponsiveHelper class

Helper class for creating responsive values that update in real-time

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

responsiveValue<T>({Widget builder(T? value)?, T? phone, T? tablet, T? laptop, T? desktop, T? tv, T? defaultValue, ResponsiveMode mode = ResponsiveMode.layoutBuilder}) Widget
Create a responsive value that updates in real-time