OverlayExt extension

on

Methods

showLoaderOnWidget<T>({GlobalKey<State<StatefulWidget>>? targetKey, BuildContext? context, required Future<T> asyncFunction(), Widget? loadingWidget, Color opacityColor = Colors.black, double opacity = 0.5, BorderRadius? borderRadius}) Future<T>

Available on GetInterface, provided by the OverlayExt extension

Displays a loading indicator over a specific widget while an asynchronous function is executed. Uses a route-scoped overlay approach to avoid conflicts with global overlay packages like ToastFiction, flutter toast, etc.
showOverlay<T>({required Future<T> asyncFunction(), Color opacityColor = Colors.black, Widget? loadingWidget, double opacity = 0.5}) Future<T>

Available on GetInterface, provided by the OverlayExt extension

Displays an overlay with a loading indicator while an asynchronous function is executed.