PercentSized extension

Enhanced responsive extension for percentage-based sizing

Example:

double fiftyPercentHeight = 50.0.hp; // 50% of screen height
double thirtyPercentWidth = 30.0.wp; // 30% of screen width
on

Properties

h → double

Available on double, provided by the PercentSized extension

Converts pixel value to responsive height based on dynamic base height.
no setter
heightPercent → double

Available on double, provided by the PercentSized extension

Returns the percentage this pixel value represents of screen height.
no setter
hp → double

Available on double, provided by the PercentSized extension

Returns the value as a percentage of the screen height.
no setter
toResponsiveHeight → double

Available on double, provided by the PercentSized extension

Converts this pixel value to actual responsive height.
no setter
toResponsiveWidth → double

Available on double, provided by the PercentSized extension

Converts this pixel value to actual responsive width.
no setter
w → double

Available on double, provided by the PercentSized extension

Converts pixel value to responsive width based on dynamic base width.
no setter
widthPercent → double

Available on double, provided by the PercentSized extension

Returns the percentage this pixel value represents of screen width.
no setter
wp → double

Available on double, provided by the PercentSized extension

Returns the value as a percentage of the screen width.
no setter