Value<T> class

Inheritance
Implemented types
Mixed-in types
Implementers
Available extensions

Constructors

Value(T val)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
listeners int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → T?
no setterinherited
status RxStatus
no setterinherited
value ↔ T?
The current value of the object.
getter/setter pairoverride

Methods

addListener(GetStateUpdate listener) Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) Disposer
inherited
append(Future<T> Function() body(), {String? errorMessage}) → void
inherited
call([T? v]) → T?
change(T? newState, {RxStatus? status}) → void
inherited
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
futurize(Future<T> body(), {String? errorMessage, bool useEmpty = false}) Future<void>
Executes a future and automatically handles the RxStatus. It will set the status to RxStatus.loading() before executing the future, and RxStatus.success() or RxStatus.error() after. If the result is null or empty, it can optionally set RxStatus.empty().
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
obx(NotifierBuilder<T?> widget, {Widget onError(String? error)?, Widget? onLoading, Widget? onEmpty}) Widget

Available on StateMixin<T>, provided by the StateExt extension

refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
toJson() → dynamic
toString() String
A string representation of this object.
override
update(void fn(T? value)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited