Inheritance
Mixed-in types
Implementers
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
no setter inherited
initialized
→ bool
Checks whether the controller has already been initialized.
no setter inherited
isClosed
→ bool
Checks whether the controller has already been closed.
no setter inherited
listeners
→ int
no setter inherited
onDelete
→ InternalFinalCallback <void >
Internal callback that starts the cycle of this controller.
final inherited
onStart
→ InternalFinalCallback <void >
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
$configureLifeCycle ()
→ void
inherited
addListener (GetStateUpdate listener )
→ Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId (Object ? key , GetStateUpdate listener )
→ Disposer
inherited
didChangeAccessibilityFeatures ()
→ void
Called when the system changes the set of currently active accessibility
features.
inherited
didChangeAppLifecycleState (AppLifecycleState state )
→ void
Called when the system puts the app in the background or returns
the app to the foreground.
inherited
didChangeLocales (List <Locale > ? locales )
→ void
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
didChangeMetrics ()
→ void
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
didChangePlatformBrightness ()
→ void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor ()
→ void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus (ViewFocusEvent event )
→ void
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
didHaveMemoryPressure ()
→ void
Called when the system is running low on memory.
inherited
didPopRoute ()
→ Future <bool >
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
didPushRoute (String route )
→ Future <bool >
Called when the host tells the application to push a new route onto the
navigator.
inherited
didPushRouteInformation (RouteInformation routeInformation )
→ Future <bool >
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit ()
→ Future <AppExitResponse >
Called when a request is received from the system to exit the application.
inherited
dispose ()
→ void
inherited
disposeId (Object id )
→ void
To dispose an id from future updates(), this ids are registered
by GetBuilder() or similar, so is a way to unlink the state change with
the Widget from the Controller.
inherited
handleCancelBackGesture ()
→ void
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
handleCommitBackGesture ()
→ void
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
handleStartBackGesture (PredictiveBackEvent backEvent )
→ bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap ()
→ void
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
handleUpdateBackGestureProgress (PredictiveBackEvent backEvent )
→ void
Called when a predictive back gesture moves.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens ()
→ void
inherited
onClose ()
→ void
Called before the controller is removed from memory.
inherited
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
onReady ()
→ void
Called 1 frame after onInit. It is the perfect place to enter
navigation events, like snack bar, dialogs, or a new route, or
async request.
inherited
refresh ()
→ void
inherited
refreshGroup (Object id )
→ void
inherited
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
removeListenerId (Object id , VoidCallback listener )
→ void
inherited
toString ()
→ String
A string representation of this object.
inherited
update ([List <Object > ? ids , bool condition = true ])
→ void
Rebuilds GetBuilder each time you call update();
Can take a List of ids, that will only update the matching
GetBuilder( id: ),
ids can be reused among GetBuilders like group tags.
The update will only notify the Widgets, if condition is true.
inherited