ResponsiveScreen class
Provides information about the screen size and type, using ContextExt.
Constructors
- ResponsiveScreen(ResponsiveScreenSettings settings)
Properties
- context ↔ BuildContext
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Returns the height of the screen.
no setter
- isDesktop → bool
-
Checks if the screen type is desktop.
no setter
- isLargeDesktop → bool
-
Checks if the screen type is large desktop.
no setter
- isLargeTablet → bool
-
Checks if the screen type is large tablet.
no setter
- isPhone → bool
-
Checks if the screen type is phone.
no setter
- isTablet → bool
-
Checks if the screen type is tablet.
no setter
- isTV → bool
-
Checks if the screen type is TV.
no setter
- isWatch → bool
-
Checks if the screen type is watch.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenType → ScreenType
-
Determines the screen type based on the device width.
no setter
- settings → ResponsiveScreenSettings
-
final
- width → double
-
Returns the width of the screen.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responsiveValue<
T> ({T? watch, T? phone, T? tablet, T? largeTablet, T? desktop, T? largeDesktop, T? tv}) → T? - Returns a value based on the screen type.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited