ResponsiveScreenSettings class
Settings for defining breakpoints for different screen types.
Constructors
Properties
- desktopChangePoint → double
-
Breakpoint for desktop screens.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- largeDesktopChangePoint → double
-
Breakpoint for large desktop screens.
final
- largeTabletChangePoint → double
-
Breakpoint for large tablet screens.
final
- phoneChangePoint → double
-
Breakpoint for phone screens.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabletChangePoint → double
-
Breakpoint for tablet screens.
final
- tvChangePoint → double
-
Breakpoint for TV screens.
final
- watchChangePoint → double
-
Breakpoint for watch screens.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited